@@ -1,5 +1,4 @@
 mod sysinfo_ffi;
-mod x11_ffi;
 
 use crate::extra;
 use crate::extra::list_dir_entries;
@@ -176,64 +175,31 @@ impl GeneralReadout for LinuxGeneralReadout {
     }
 
     fn resolution(&self) -> Result<String, ReadoutError> {
-        fn get_resolution_without_x() -> Result<String, ReadoutError> {
-            let drm = std::path::Path::new("/sys/class/drm");
-            if drm.is_dir() {
-                let dirs = extra::list_dir_entries(drm);
-                let mut resolution = String::new();
-                for entry in dirs {
-                    if entry.read_link().is_ok() {
-                        let modes = std::path::PathBuf::from(entry).join("modes");
-                        if modes.is_file() {
-                            if let Ok(file) = std::fs::File::open(modes) {
-                                if let Some(line) = BufReader::new(file).lines().nth(0) {
-                                    if let Ok(mut str) = line {
-                                        str.pop();
-                                        resolution.push_str(&str);
-                                        resolution.push_str(", ");
-                                    }
+        let drm = std::path::Path::new("/sys/class/drm");
+        if drm.is_dir() {
+            let dirs = extra::list_dir_entries(drm);
+            let mut resolutions: Vec<String> = Vec::new();
+            for entry in dirs {
+                if entry.read_link().is_ok() {
+                    let modes = std::path::PathBuf::from(entry).join("modes");
+                    if modes.is_file() {
+                        if let Ok(file) = std::fs::File::open(modes) {
+                            if let Some(line) = BufReader::new(file).lines().nth(0) {
+                                if let Ok(str) = line {
+                                    resolutions.push(str);
                                 }
                             }
                         }
                     }
                 }
-
-                if resolution.trim_end().ends_with(",") {
-                    resolution.pop();
-                }
-
-                Ok(resolution)
-            } else {
-                Err(ReadoutError::Other(String::from(
-                    "Could not obtain screen resolution from /sys/class/drm",
-                )))
             }
+
+            return Ok(resolutions.join(", "));
         }
 
-        if cfg!(feature = "xserver") {
-            use std::os::raw::c_char;
-            use x11_ffi::*;
-
-            let display_name: *const c_char = std::ptr::null_mut();
-            let display = unsafe { XOpenDisplay(display_name) };
-
-            if !display.is_null() {
-                let screen = unsafe { XDefaultScreen(display) };
-                let width = unsafe { XDisplayWidth(display, screen) };
-                let height = unsafe { XDisplayHeight(display, screen) };
-
-                unsafe {
-                    XCloseDisplay(display);
-                    libc::free(display_name as *mut libc::c_void);
-                }
-
-                return Ok(format!("{}x{}", width, height));
-            } else {
-                return get_resolution_without_x();
-            }
-        } else {
-            return get_resolution_without_x();
-        }
+        Err(ReadoutError::Other(String::from(
+            "Could not obtain screen resolution from /sys/class/drm",
+        )))
     }
 
     fn machine(&self) -> Result<String, ReadoutError> {
